==> jc-1.4.0.tar.gz: javax/security/auth/callback/NameCallback.h <==
// public class javax.security.auth.callback.NameCallback

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 6087ffe40200f556 javax_security_auth_callback_NameCallback

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_security_auth_callback_NameCallback_H_
#define _JC_javax_security_auth_callback_NameCallback_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_javax_security_auth_callback_NameCallback$sub_refs	_jc_javax_security_auth_callback_NameCallback$sub_refs;
typedef struct _jc_javax_security_auth_callback_NameCallback$sub_nonrefs	_jc_javax_security_auth_callback_NameCallback$sub_nonrefs;
typedef struct _jc_javax_security_auth_callback_NameCallback$refs	_jc_javax_security_auth_callback_NameCallback$refs;
typedef struct _jc_javax_security_auth_callback_NameCallback$nonrefs	_jc_javax_security_auth_callback_NameCallback$nonrefs;
typedef struct _jc_javax_security_auth_callback_NameCallback$object	_jc_javax_security_auth_callback_NameCallback$object;

typedef const struct _jc_javax_security_auth_callback_NameCallback$vmethods	_jc_javax_security_auth_callback_NameCallback$vmethods;
typedef const struct _jc_javax_security_auth_callback_NameCallback$vtable	_jc_javax_security_auth_callback_NameCallback$vtable;
typedef const struct _jc_javax_security_auth_callback_NameCallback$vtype	_jc_javax_security_auth_callback_NameCallback$vtype;

// Constructors
extern void _jc_javax_security_auth_callback_NameCallback$method$_init$c31b894660454d13(_jc_env *, struct _jc_javax_security_auth_callback_NameCallback$object *, struct _jc_java_lang_String$object *);
extern void _jc_javax_security_auth_callback_NameCallback$method$_init$a34354cd9552963f(_jc_env *, struct _jc_javax_security_auth_callback_NameCallback$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *);

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_javax_security_auth_callback_NameCallback$method$getDefaultName$aeb04242ec37c155(_jc_env *, struct _jc_javax_security_auth_callback_NameCallback$object *);
extern struct _jc_java_lang_String$object *_jc_javax_security_auth_callback_NameCallback$method$getName$bec186f2ce7e1882(_jc_env *, struct _jc_javax_security_auth_callback_NameCallback$object *);
extern struct _jc_java_lang_String$object *_jc_javax_security_auth_callback_NameCallback$method$getPrompt$ad6bd756fb4800ba(_jc_env *, struct _jc_javax_security_auth_callback_NameCallback$object *);
extern void _jc_javax_security_auth_callback_NameCallback$method$setDefaultName$a327a609b8cb1f58(_jc_env *, struct _jc_javax_security_auth_callback_NameCallback$object *, struct _jc_java_lang_String$object *);
extern void _jc_javax_security_auth_callback_NameCallback$method$setName$c9ac040f8ec96d00(_jc_env *, struct _jc_javax_security_auth_callback_NameCallback$object *, struct _jc_java_lang_String$object *);
extern void _jc_javax_security_auth_callback_NameCallback$method$setPrompt$7b347b9990ff5882(_jc_env *, struct _jc_javax_security_auth_callback_NameCallback$object *, struct _jc_java_lang_String$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_security_auth_callback_NameCallback$method_info$getDefaultName$aeb04242ec37c155;
extern _jc_method _jc_javax_security_auth_callback_NameCallback$method_info$getName$bec186f2ce7e1882;
extern _jc_method _jc_javax_security_auth_callback_NameCallback$method_info$getPrompt$ad6bd756fb4800ba;
extern _jc_method _jc_javax_security_auth_callback_NameCallback$method_info$setDefaultName$a327a609b8cb1f58;
extern _jc_method _jc_javax_security_auth_callback_NameCallback$method_info$setName$c9ac040f8ec96d00;
extern _jc_method _jc_javax_security_auth_callback_NameCallback$method_info$setPrompt$7b347b9990ff5882;

// Virtual methods structure
struct _jc_javax_security_auth_callback_NameCallback$vmethods {
	struct _jc_java_lang_String$object	*(*getDefaultName$aeb04242ec37c155)(_jc_env *, struct _jc_javax_security_auth_callback_NameCallback$object *);
	struct _jc_java_lang_String$object	*(*getName$bec186f2ce7e1882)(_jc_env *, struct _jc_javax_security_auth_callback_NameCallback$object *);
	struct _jc_java_lang_String$object	*(*getPrompt$ad6bd756fb4800ba)(_jc_env *, struct _jc_javax_security_auth_callback_NameCallback$object *);
	void	(*setDefaultName$a327a609b8cb1f58)(_jc_env *, struct _jc_javax_security_auth_callback_NameCallback$object *, struct _jc_java_lang_String$object *);
	void	(*setName$c9ac040f8ec96d00)(_jc_env *, struct _jc_javax_security_auth_callback_NameCallback$object *, struct _jc_java_lang_String$object *);
	void	(*setPrompt$7b347b9990ff5882)(_jc_env *, struct _jc_javax_security_auth_callback_NameCallback$object *, struct _jc_java_lang_String$object *);
};

// Vtable
struct _jc_javax_security_auth_callback_NameCallback$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_security_auth_callback_NameCallback$vmethods	javax_security_auth_callback_NameCallback;
};

// Vtype
struct _jc_javax_security_auth_callback_NameCallback$vtype {
	_jc_type			type;
	_jc_javax_security_auth_callback_NameCallback$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_security_auth_callback_NameCallback$sub_refs {
	struct _jc_java_lang_String$object	*prompt;
	struct _jc_java_lang_String$object	*defaultName;
	struct _jc_java_lang_String$object	*inputName;
};

// Reference instance fields (object)
struct _jc_javax_security_auth_callback_NameCallback$refs {
    _jc_javax_security_auth_callback_NameCallback$sub_refs	javax_security_auth_callback_NameCallback;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_security_auth_callback_NameCallback$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_security_auth_callback_NameCallback$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_security_auth_callback_NameCallback$sub_nonrefs	javax_security_auth_callback_NameCallback;
};

// Object instance structure
struct _jc_javax_security_auth_callback_NameCallback$object {
	_jc_javax_security_auth_callback_NameCallback$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_security_auth_callback_NameCallback$vtype	*vtype;
	_jc_javax_security_auth_callback_NameCallback$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_security_auth_callback_NameCallback$vtype _jc_javax_security_auth_callback_NameCallback$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_security_auth_callback_NameCallback, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_security_auth_callback_NameCallback$class_object;

#endif	/* _JC_javax_security_auth_callback_NameCallback_H_ */

==> jc-1.4.6.tar.gz: javax/security/auth/callback/NameCallback.h <==
// public class javax.security.auth.callback.NameCallback

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 6087ffe40200f556 javax_security_auth_callback_NameCallback

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_security_auth_callback_NameCallback_H_
#define _JC_javax_security_auth_callback_NameCallback_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_javax_security_auth_callback_NameCallback$sub_refs	_jc_javax_security_auth_callback_NameCallback$sub_refs;
typedef struct _jc_javax_security_auth_callback_NameCallback$sub_nonrefs	_jc_javax_security_auth_callback_NameCallback$sub_nonrefs;
typedef struct _jc_javax_security_auth_callback_NameCallback$refs	_jc_javax_security_auth_callback_NameCallback$refs;
typedef struct _jc_javax_security_auth_callback_NameCallback$nonrefs	_jc_javax_security_auth_callback_NameCallback$nonrefs;
typedef struct _jc_javax_security_auth_callback_NameCallback$object	_jc_javax_security_auth_callback_NameCallback$object;

typedef const struct _jc_javax_security_auth_callback_NameCallback$vmethods	_jc_javax_security_auth_callback_NameCallback$vmethods;
typedef const struct _jc_javax_security_auth_callback_NameCallback$vtable	_jc_javax_security_auth_callback_NameCallback$vtable;
typedef const struct _jc_javax_security_auth_callback_NameCallback$vtype	_jc_javax_security_auth_callback_NameCallback$vtype;

// Constructors
extern void _jc_javax_security_auth_callback_NameCallback$method$_init$c31b894660454d13(_jc_env *, struct _jc_javax_security_auth_callback_NameCallback$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern void _jc_javax_security_auth_callback_NameCallback$method$_init$a34354cd9552963f(_jc_env *, struct _jc_javax_security_auth_callback_NameCallback$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_javax_security_auth_callback_NameCallback$method$getDefaultName$aeb04242ec37c155(_jc_env *, struct _jc_javax_security_auth_callback_NameCallback$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_javax_security_auth_callback_NameCallback$method$getName$bec186f2ce7e1882(_jc_env *, struct _jc_javax_security_auth_callback_NameCallback$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_javax_security_auth_callback_NameCallback$method$getPrompt$ad6bd756fb4800ba(_jc_env *, struct _jc_javax_security_auth_callback_NameCallback$object *) _JC_JCNI_ATTR;
extern void _jc_javax_security_auth_callback_NameCallback$method$setDefaultName$a327a609b8cb1f58(_jc_env *, struct _jc_javax_security_auth_callback_NameCallback$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern void _jc_javax_security_auth_callback_NameCallback$method$setName$c9ac040f8ec96d00(_jc_env *, struct _jc_javax_security_auth_callback_NameCallback$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern void _jc_javax_security_auth_callback_NameCallback$method$setPrompt$7b347b9990ff5882(_jc_env *, struct _jc_javax_security_auth_callback_NameCallback$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_security_auth_callback_NameCallback$method_info$getDefaultName$aeb04242ec37c155;
extern _jc_method _jc_javax_security_auth_callback_NameCallback$method_info$getName$bec186f2ce7e1882;
extern _jc_method _jc_javax_security_auth_callback_NameCallback$method_info$getPrompt$ad6bd756fb4800ba;
extern _jc_method _jc_javax_security_auth_callback_NameCallback$method_info$setDefaultName$a327a609b8cb1f58;
extern _jc_method _jc_javax_security_auth_callback_NameCallback$method_info$setName$c9ac040f8ec96d00;
extern _jc_method _jc_javax_security_auth_callback_NameCallback$method_info$setPrompt$7b347b9990ff5882;

// Virtual methods structure
struct _jc_javax_security_auth_callback_NameCallback$vmethods {
	struct _jc_java_lang_String$object	*(*getDefaultName$aeb04242ec37c155)(_jc_env *, struct _jc_javax_security_auth_callback_NameCallback$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*getName$bec186f2ce7e1882)(_jc_env *, struct _jc_javax_security_auth_callback_NameCallback$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*getPrompt$ad6bd756fb4800ba)(_jc_env *, struct _jc_javax_security_auth_callback_NameCallback$object *) _JC_JCNI_ATTR;
	void	(*setDefaultName$a327a609b8cb1f58)(_jc_env *, struct _jc_javax_security_auth_callback_NameCallback$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
	void	(*setName$c9ac040f8ec96d00)(_jc_env *, struct _jc_javax_security_auth_callback_NameCallback$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
	void	(*setPrompt$7b347b9990ff5882)(_jc_env *, struct _jc_javax_security_auth_callback_NameCallback$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_security_auth_callback_NameCallback$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_security_auth_callback_NameCallback$vmethods	javax_security_auth_callback_NameCallback;
};

// Vtype
struct _jc_javax_security_auth_callback_NameCallback$vtype {
	_jc_type			type;
	_jc_javax_security_auth_callback_NameCallback$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_security_auth_callback_NameCallback$sub_refs {
	struct _jc_java_lang_String$object	*prompt;
	struct _jc_java_lang_String$object	*defaultName;
	struct _jc_java_lang_String$object	*inputName;
};

// Reference instance fields (object)
struct _jc_javax_security_auth_callback_NameCallback$refs {
    _jc_javax_security_auth_callback_NameCallback$sub_refs	javax_security_auth_callback_NameCallback;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_security_auth_callback_NameCallback$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_security_auth_callback_NameCallback$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_security_auth_callback_NameCallback$sub_nonrefs	javax_security_auth_callback_NameCallback;
};

// Object instance structure
struct _jc_javax_security_auth_callback_NameCallback$object {
	_jc_javax_security_auth_callback_NameCallback$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_security_auth_callback_NameCallback$vtype	*vtype;
	_jc_javax_security_auth_callback_NameCallback$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_security_auth_callback_NameCallback$vtype _jc_javax_security_auth_callback_NameCallback$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_security_auth_callback_NameCallback, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_security_auth_callback_NameCallback$class_object;

#endif	/* _JC_javax_security_auth_callback_NameCallback_H_ */
